summaryrefslogtreecommitdiffstats
path: root/functest/core/singlevm.py
diff options
context:
space:
mode:
authorCédric Ollivier <cedric.ollivier@orange.com>2018-08-19 12:43:11 +0200
committerCédric Ollivier <cedric.ollivier@orange.com>2018-08-19 12:44:41 +0200
commita87bbcb1fe325be52b70428baf08ec6b8198a946 (patch)
treec8688c684bf4c86dd8ca69c4fb1cc950f4585f65 /functest/core/singlevm.py
parent8eac5dbbadc42122dea6c82edf14fdb4481c5e63 (diff)
Typos (ressources)
Change-Id: Ifcf1d4bd48b64bc9175c3b0d594f897f4f3f5e7d Signed-off-by: Cédric Ollivier <cedric.ollivier@orange.com> (cherry picked from commit 873e5f5c868027d34f36d494719b4dad2bdb1e7d)
Diffstat (limited to 'functest/core/singlevm.py')
-rw-r--r--functest/core/singlevm.py14
1 files changed, 7 insertions, 7 deletions
diff --git a/functest/core/singlevm.py b/functest/core/singlevm.py
index 500a44b59..78f8ab9d0 100644
--- a/functest/core/singlevm.py
+++ b/functest/core/singlevm.py
@@ -9,7 +9,7 @@
"""Ease deploying a single VM reachable via ssh
-It offers a simple way to create all tenant network ressources + a VM for
+It offers a simple way to create all tenant network resources + a VM for
advanced testcases (e.g. deploying an orchestrator).
"""
@@ -257,14 +257,14 @@ class VmReady1(tenantnetwork.TenantNetwork1):
if self.flavor:
self.orig_cloud.delete_flavor(self.flavor.id)
except Exception: # pylint: disable=broad-except
- self.__logger.exception("Cannot clean all ressources")
+ self.__logger.exception("Cannot clean all resources")
class VmReady2(VmReady1):
"""Deploy a single VM reachable via ssh (scenario2)
It creates new user/project before creating and configuring all tenant
network ressources, flavors, images, etc. required by advanced testcases.
It ensures that all testcases inheriting from SingleVm2 could work
without specific configurations (or at least read the same config data).
@@ -293,7 +293,7 @@ class VmReady2(VmReady1):
assert self.project
self.project.clean()
except Exception: # pylint: disable=broad-except
- self.__logger.exception("Cannot clean all ressources")
+ self.__logger.exception("Cannot clean all resources")
class SingleVm1(VmReady1):
@@ -449,14 +449,14 @@ class SingleVm1(VmReady1):
self.cloud.delete_keypair(self.keypair.name)
super(SingleVm1, self).clean()
except Exception: # pylint: disable=broad-except
- self.__logger.exception("Cannot clean all ressources")
+ self.__logger.exception("Cannot clean all resources")
class SingleVm2(SingleVm1):
"""Deploy a single VM reachable via ssh (scenario2)
It creates new user/project before creating and configuring all tenant
network ressources and vms required by advanced testcases.
It ensures that all testcases inheriting from SingleVm2 could work
without specific configurations (or at least read the same config data).
@@ -485,4 +485,4 @@ class SingleVm2(SingleVm1):
assert self.project
self.project.clean()
except Exception: # pylint: disable=broad-except
- self.__logger.exception("Cannot clean all ressources")
+ self.__logger.exception("Cannot clean all resources")
@@ -257,14 +257,14 @@ class VmReady1(tenantnetwork.TenantNetwork1):
"""Deploy a single VM reachable via ssh (scenario2)
It creates new user/project before creating and configuring all tenant
- network ressources, flavors, images, etc. required by advanced testcases.
+ network resources, flavors, images, etc. required by advanced testcases.
It ensures that all testcases inheriting from SingleVm2 could work
without specific configurations (or at least read the same config data).
@@ -449,14 +449,14 @@ class SingleVm1(VmReady1):
"""Deploy a single VM reachable via ssh (scenario2)
It creates new user/project before creating and configuring all tenant
- network ressources and vms required by advanced testcases.
+ network resources and vms required by advanced testcases.
It ensures that all testcases inheriting from SingleVm2 could work
without specific configurations (or at least read the same config data).